visual-cortex-capture 0.2.1

Screen-capture abstraction for visual-cortex: frames, regions, rates, the FrameSource trait, and the macOS ScreenCaptureKit backend.
docs.rs failed to build visual-cortex-capture-0.2.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: visual-cortex-capture-0.2.0

Screen capture abstraction: frames, regions, rates, and the FrameSource trait.